class DataTypeParseError(Exception):
    """
    Exception raised when there is an error parsing data type.
    """


class ValidationError(Exception):
    """
    Exception raised when a validation error occurs.
    """


class SerializationError(Exception):
    """
    Exception raised when a serialization error occurs.
    """
